Improve this Doc View Source

NOTE: This is not an injectable instance, just a globally available function.

Method for serializing common angular objects (scope, elements, etc..) into strings. It is useful for logging objects to the console when debugging.

## Usage

`angular.mock.dump(object);`

### Arguments

Param | Type | Details
--- | --- | ---
object | * | any object to turn into string.

### Returns

string | a serialized string of the argument